==> fsm-api-1.2.0-sources.jar: ch/bbv/fsm/events/TransitionEventArgs.java <==
/*******************************************************************************
 *  Copyright 2010, 2011 bbv Software Services AG, Ueli Kurmann
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 * Contributors:
 *     bbv Software Services AG (http://www.bbv.ch), Ueli Kurmann
 *******************************************************************************/
package ch.bbv.fsm.events;

/**
 * Defines a transition event argument.
 * 
 * @author Ueli Kurmann (bbv Software Services AG) (bbv Software Services AG)
 * @param <TState>
 *            the type of the states.
 * @param <TEvent>
 *            the type of the events.
 */
public interface TransitionEventArgs<TState, TEvent> extends ContextEventArgs<TState, TEvent> {

    /**
     * Returns the event arguments.
     * 
     * @return the event arguments.
     */
    public abstract Object[] getEventArguments();

    /**
     * Returns the event id of the transition.
     * 
     * @return the event id of the transition.
     */
    public abstract TEvent getEventId();

    /**
     * Returns the id of the source state of the transition.
     * 
     * @return the id of the source state of the transition.
     */
    public abstract TState getStateId();

}

==> fsm-api-2.0.0-sources.jar: ch/bbv/fsm/events/TransitionEventArgs.java <==
/*******************************************************************************
 *  Copyright 2010, 2011 bbv Software Services AG, Ueli Kurmann
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 * Contributors:
 *     bbv Software Services AG (http://www.bbv.ch), Ueli Kurmann
 *******************************************************************************/
package ch.bbv.fsm.events;

import ch.bbv.fsm.StateMachine;

/**
 * Defines a transition event argument.
 * 
 * @author Ueli Kurmann (bbv Software Services AG) (bbv Software Services AG)
 * @param <TState>
 *            the type of the states.
 * @param <TEvent>
 *            the type of the events.
 * @param <TStateMachine>
 *            the type of the statemachine
 */
public interface TransitionEventArgs<TStateMachine extends StateMachine<TState, TEvent>, TState extends Enum<?>, TEvent extends Enum<?>>
		extends ContextEventArgs<TStateMachine, TState, TEvent> {

	/**
	 * Returns the event arguments.
	 * 
	 * @return the event arguments.
	 */
	Object[] getEventArguments();

	/**
	 * Returns the event id of the transition.
	 * 
	 * @return the event id of the transition.
	 */
	TEvent getEventId();

	/**
	 * Returns the id of the source state of the transition.
	 * 
	 * @return the id of the source state of the transition.
	 */
	TState getStateId();

}
